/*
 * This job renders `data` using nunjucks template `type`
 */

var nunjucks = require('nunjucks');
var fs = require('fs');
var dateFilter = require('nunjucks-date-filter');
var util = require('util');

var watch = require('./config').watch;
console.log('watch: '+watch);
var env = new nunjucks.Environment(
  new nunjucks.FileSystemLoader('theme/templates',{watch: watch})
);

env.addFilter('date', dateFilter);

env.addFilter('paginationList', function(page, count) {
    var curPage = page;
    var pages = [];
    pages.push(curPage);
    for(var i = 0; i < count; i++) {
      curPage = curPage.metadata.prevpage;
      if(curPage === undefined) break;
      pages.unshift(curPage);
    }

    curPage = page;
    for(var i = 0; i < count; i++) {
      curPage = curPage.metadata.nextpage;
      if(curPage === undefined) break;
      pages.push(curPage);
    }
    return pages;
});

env.addFilter('inspect', function(obj) {
    return util.inspect(obj);
});

env.addFilter('relURL', function(filename, dir){
  if(filename.substr(0,1) == '/' || filename.match('://')) return filename;
  if(dir.substr(0,1) !== '/') dir = '/' + dir;
  if(filename.match(/\/$/)) return dir+filename;
  return dir+'/'+filename;
})

module.exports = function(data, type) {
  return new Promise(function(resolve, reject) {
    env.getTemplate(type+'.html.nunj', true, function(err, tmpl) {
      if(err) reject(new Error('Failed to load template '+type+'.html.nunj'));
      resolve(tmpl);
    });
  }).then(function(tmpl) {
    return tmpl.render(data);
  });
}
